@@ -16,11 +16,12 @@ enum LanguageID
 	MEnableDesktopNotifications,
 	MEnterExecRemotely,
 	MSmartSymlinksCopy,
-	MUMaskOverride,
+	MUseOfChmod,
+	MUseOfChmod_Auto,
+	MUseOfChmod_Always,
+	MUseOfChmod_Never,
 	MRememberDirectory,
 	MConnPoolExpiration,
-	MConnectUsingProxy,
-	MEditTSocksConfig,
 
 	MRememberChoice,
 	MOperationFailed,
@@ -48,6 +49,7 @@ enum LanguageID
 	MDisplayName,
 	MExtraOptions,
 	MProtocolOptions,
+	MProxyOptions,
 	MSave,
 	MConnect,
 	MSaveConnect,
@@ -277,6 +279,9 @@ enum LanguageID
 	MModeUser,
 	MModeGroup,
 	MModeOther,
+	MModeReadHot,
+	MModeWriteHot,
+	MModeExecuteHot,
 	MModeRead,
 	MModeWrite,
 	MModeExecute,
@@ -305,5 +310,11 @@ enum LanguageID
 
 	MSHELLOptionsTitle,
 	MSHELLWay,
-	MSHELLWaySettings
+	MSHELLWaySettings,
+
+	MProxySettingsTitle,
+	MProxySettingsDisabled,
+	MProxySettingsKind,
+	MProxySettingsEdit,
+
 };
