@@ -74,6 +74,9 @@ extern "C" {
 	WINPORT_DECL(SetConsoleWindowMaximized,VOID,(BOOL Maximized));
 	WINPORT_DECL(GetConsoleColorPalette,BYTE,(HANDLE hConsoleOutput)); // Returns current color resolution: 4, 8, 24
 
+	WINPORT_DECL(GetConsoleBasePalette,VOID,(HANDLE hConsoleOutput, void *p));
+	WINPORT_DECL(SetConsoleBasePalette,BOOL,(HANDLE hConsoleOutput, void *p));
+
 	WINPORT_DECL(GenerateConsoleCtrlEvent, BOOL, (DWORD dwCtrlEvent, DWORD dwProcessGroupId ));
 	WINPORT_DECL(SetConsoleCtrlHandler, BOOL, (PHANDLER_ROUTINE HandlerRoutine, BOOL Add ));
 	
