@@ -783,20 +783,17 @@ DWORD64 TTYBackend::OnConsoleSetTweaks(DWORD64 tweaks)
 	}
 
 	bool override_default_palette = (tweaks & CONSOLE_TTY_PALETTE_OVERRIDE) != 0;
-
 	{
 		std::lock_guard<std::mutex> lock(_palette_mtx);
 		std::swap(override_default_palette, _override_default_palette);
 	}
 
 	if (override_default_palette != ((tweaks & CONSOLE_TTY_PALETTE_OVERRIDE) != 0)) {
-		{
-			std::unique_lock<std::mutex> lock(_async_mutex);
-			_ae.palette = true;
-			_async_cond.notify_all();
-			while (_ae.palette) {
-				_async_cond.wait(lock);
-			}
+		std::unique_lock<std::mutex> lock(_async_mutex);
+		_ae.palette = true;
+		_async_cond.notify_all();
+		while (_ae.palette) {
+			_async_cond.wait(lock);
 		}
 	}
 
@@ -836,6 +833,32 @@ void TTYBackend::OnConsoleOverrideColor(DWORD Index, DWORD *ColorFG, DWORD *Colo
 	}
 }
 
+void TTYBackend::OnConsoleGetBasePalette(void *pbuff)
+{
+	memcpy(pbuff, &g_winport_palette, BASE_PALETTE_SIZE * sizeof(DWORD) * 2);
+
+	return;
+}
+
+bool TTYBackend::OnConsoleSetBasePalette(void *pbuff)
+{
+	if (!pbuff) return false;
+
+	{
+		std::unique_lock<std::mutex> lock(_palette_mtx);
+		memcpy(&_palette, pbuff, BASE_PALETTE_SIZE * sizeof(DWORD) * 2);
+	}
+
+	std::unique_lock<std::mutex> lock(_async_mutex);
+	_ae.palette = true;
+	_async_cond.notify_all();
+	while (_ae.palette) {
+		_async_cond.wait(lock);
+	}
+
+	return true;
+}
+
 void TTYBackend::OnConsoleChangeFont()
 {
 }
@@ -1026,11 +1049,7 @@ void TTYBackend::OnInspectKeyEvent(KEY_EVENT_RECORD &event)
 	}
 
 	if (!event.wVirtualKeyCode) {
-		if (event.dwControlKeyState & (LEFT_CTRL_PRESSED | RIGHT_CTRL_PRESSED | LEFT_ALT_PRESSED | RIGHT_ALT_PRESSED)) {
-			event.wVirtualKeyCode = WChar2WinVKeyCode(event.uChar.UnicodeChar);
-		} else {
-			event.wVirtualKeyCode = VK_UNASSIGNED;
-		}
+		event.wVirtualKeyCode = WChar2WinVKeyCode(event.uChar.UnicodeChar);
 	}
 	if (!event.uChar.UnicodeChar && IsEnhancedKey(event.wVirtualKeyCode)) {
 		event.dwControlKeyState|= ENHANCED_KEY;
