@@ -46,9 +46,9 @@ void TTYOutput::TrueColors::AppendSuffix(std::string &out, DWORD rgb)
 	char buf[64];
 	const auto &it = _colors256_lookup.find(rgb);
 	if (it != _colors256_lookup.end()) {
-		sprintf(buf, "5;%u;", ((unsigned int)it->second) + 16);
+		snprintf(buf, sizeof(buf), "5;%u;", ((unsigned int)it->second) + 16);
 	} else {
-		sprintf(buf, "2;%u;%u;%u;", rgb & 0xff, (rgb >> 8) & 0xff, (rgb >> 16) & 0xff);
+		snprintf(buf, sizeof(buf), "2;%u;%u;%u;", rgb & 0xff, (rgb >> 8) & 0xff, (rgb >> 16) & 0xff);
 	}
 	out+= buf;
 }
@@ -284,11 +284,11 @@ void TTYOutput::FinalizeSameChars()
 		int sz_len;
 		if (_far2l_tty) {
 			_rawbuf.insert(_rawbuf.end(), _same_chars.tmp.begin(), _same_chars.tmp.end());
-			sz_len = sprintf(sz, // repeat last character <count-1> times
-				ESC "[%ub", _same_chars.count - 1);
+			sz_len = snprintf(sz, // repeat last character <count-1> times
+				sizeof(sz), ESC "[%ub", _same_chars.count - 1);
 		} else {
-			sz_len = sprintf(sz, // erase <count> chars and move cursor forward by <count>
-				ESC "[%uX" ESC "[%uC", _same_chars.count, _same_chars.count);
+			sz_len = snprintf(sz, // erase <count> chars and move cursor forward by <count>
+				sizeof(sz), ESC "[%uX" ESC "[%uC", _same_chars.count, _same_chars.count);
 		}
 		if (sz_len >= 0) {
 			assert(size_t(sz_len) <= ARRAYSIZE(sz));
