@@ -357,6 +357,8 @@ WinPortFrame::WinPortFrame(const wxString& title)
 
 	// far2l doesn't need special erase background
 	SetBackgroundStyle(wxBG_STYLE_PAINT);
+	const auto bkclr = g_wx_palette.background[0];
+	SetBackgroundColour(wxColour(bkclr.r, bkclr.g, bkclr.b));
 	Create(NULL, wxID_ANY, title, _win_state.pos, _win_state.size, style);
 	_panel = new WinPortPanel(this, wxPoint(0, 0), GetClientSize());
 	_panel->SetFocus();
@@ -434,6 +436,7 @@ void WinPortFrame::OnEraseBackground(wxEraseEvent &event)
 void WinPortFrame::OnPaint(wxPaintEvent &event)
 {
 	wxPaintDC dc(this);
+	dc.Clear();
 }
 
 void WinPortFrame::OnChar(wxKeyEvent &event)
@@ -1199,7 +1202,7 @@ void WinPortPanel::OnKeyDown( wxKeyEvent& event )
 #endif
 
 	if ( (dwMods != 0 && event.GetUnicodeKey() < 32)
-		|| (dwMods & (RIGHT_CTRL_PRESSED | LEFT_ALT_PRESSED)) != 0
+		|| (dwMods & (LEFT_CTRL_PRESSED | RIGHT_CTRL_PRESSED | LEFT_ALT_PRESSED)) != 0
 		|| event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_RETURN
 		|| (event.GetUnicodeKey()==WXK_NONE && !IsForcedCharTranslation(event.GetKeyCode()) ))
 	{
@@ -1814,6 +1817,27 @@ static void ConsoleOverrideColorInMain(DWORD Index, DWORD *ColorFG, DWORD *Color
 	g_wx_palette.background[Index] = bk;
 }
 
+static void ConsoleOverrideBasePaletteInMain(void *pbuff)
+{
+	memcpy(&g_wx_palette, pbuff, BASE_PALETTE_SIZE * sizeof(WinPortRGB) * 2);
+}
+
+void WinPortPanel::OnConsoleGetBasePalette(void *pbuff)
+{
+	memcpy(pbuff, &g_wx_palette, BASE_PALETTE_SIZE * sizeof(WinPortRGB) * 2);
+}
+
+bool WinPortPanel::OnConsoleSetBasePalette(void *pbuff)
+{
+	if (!pbuff)
+		return false;
+
+	auto fn = std::bind(&ConsoleOverrideBasePaletteInMain, pbuff);
+	CallInMainNoRet(fn);
+
+	return true;
+}
+
 void WinPortPanel::OnConsoleOverrideColor(DWORD Index, DWORD *ColorFG, DWORD *ColorBK)
 {
 	if (Index >= BASE_PALETTE_SIZE) {
