@@ -1,10 +1,8 @@
 #ifndef _COLORER_STYLEDHRDMAPPER_H_
 #define _COLORER_STYLEDHRDMAPPER_H_
 
-#include <colorer/io/Writer.h>
-#include <colorer/handlers/RegionMapperImpl.h>
-#include <colorer/handlers/StyledRegion.h>
-#include <colorer/xml/XmlInputSource.h>
+#include "colorer/handlers/RegionMapper.h"
+#include "colorer/handlers/StyledRegion.h"
 
 /** HRD files reader.
     HRD Files format contains mappings of HRC syntax regions into
@@ -14,28 +12,26 @@
 
     @ingroup colorer_handlers
 */
-class StyledHRDMapper : public RegionMapperImpl
+class StyledHRDMapper : public RegionMapper
 {
-public:
-  StyledHRDMapper();
-  ~StyledHRDMapper();
+ public:
+  StyledHRDMapper() = default;
+  ~StyledHRDMapper() override;
 
   /** Loads region defines from @c is InputSource
-  */
-  void loadRegionMappings(XmlInputSource* is);
+   */
+  void loadRegionMappings(XmlInputSource& is) override;
   /** Saves all loaded region defines into @c writer.
       Note, that result document would not be equal
       to input one, because there could be multiple input
       documents.
   */
-  void saveRegionMappings(Writer* writer) const;
+  void saveRegionMappings(Writer* writer) const override;
   /** Changes specified region definition to @c rdnew
       @param region Region full qualified name.
       @param rdnew  New region definition to replace old one
   */
-  void setRegionDefine(const String &region, const RegionDefine* rdnew);
+  void setRegionDefine(const UnicodeString& region, const RegionDefine* rdnew) override;
 };
 
 #endif
-
-
