@@ -34,6 +34,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "headers.hpp"
 
 #include <algorithm>
+#include <langinfo.h> // for nl_langinfo
 #include "config.hpp"
 #include "lang.hpp"
 #include "language.hpp"
@@ -177,10 +178,23 @@ void SystemSettings()
 				DIF_DROPDOWNLIST | DIF_LISTAUTOHIGHLIGHT | DIF_LISTWRAPMODE);
 	MakeLinkSuggest->Indent(4);
 
+	Builder.AddSeparator();
 	AddHistorySettings(Builder, Msg::ConfigSaveHistory, &Opt.SaveHistory, &Opt.HistoryCount);
 	AddHistorySettings(Builder, Msg::ConfigSaveFoldersHistory, &Opt.SaveFoldersHistory,
 			&Opt.FoldersHistoryCount);
 	AddHistorySettings(Builder, Msg::ConfigSaveViewHistory, &Opt.SaveViewHistory, &Opt.ViewHistoryCount);
+	DialogBuilderListItem CAHistRemoveListItems[] = {
+			{Msg::ConfigHistoryRemoveDupsRuleNever, 0},
+			{Msg::ConfigHistoryRemoveDupsRuleByName, 1},
+			{Msg::ConfigHistoryRemoveDupsRuleByNameExtra, 2},
+	};
+	DialogItemEx *HistRemove =
+		Builder.AddComboBox((int *)&Opt.HistoryRemoveDupsRule, 20, CAHistRemoveListItems, ARRAYSIZE(CAHistRemoveListItems),
+				DIF_DROPDOWNLIST | DIF_LISTAUTOHIGHLIGHT | DIF_LISTWRAPMODE);
+	Builder.AddTextBefore(HistRemove, Msg::ConfigHistoryRemoveDupsRule);
+
+	Builder.AddCheckbox(Msg::ConfigAutoHighlightHistory, &Opt.AutoHighlightHistory);
+	Builder.AddSeparator();
 
 	Builder.AddCheckbox(Msg::ConfigAutoSave, &Opt.AutoSaveSetup);
 	Builder.AddOKCancel();
@@ -200,6 +214,7 @@ void PanelSettings()
 	Builder.AddCheckbox(Msg::ConfigHighlight, &Opt.Highlight);
 	Builder.AddCheckbox(Msg::ConfigAutoChange, &Opt.Tree.AutoChangeFolder);
 	Builder.AddCheckbox(Msg::ConfigSelectFolders, &Opt.SelectFolders);
+	Builder.AddCheckbox(Msg::ConfigCaseSensitiveCompareSelect, &Opt.PanelCaseSensitiveCompareSelect);
 	Builder.AddCheckbox(Msg::ConfigSortFolderExt, &Opt.SortFolderExt);
 	Builder.AddCheckbox(Msg::ConfigReverseSort, &Opt.ReverseSort);
 
@@ -290,6 +305,14 @@ void InputSettings()
 */
 void InterfaceSettings()
 {
+	int DateFormatIndex = GetDateFormat(); //Opt.DateFormat
+	FARString strDateSeparator; //Opt.strDateSeparator
+	FARString strTimeSeparator; //Opt.strTimeSeparator
+	FARString strDecimalSeparator; //Opt.strDecimalSeparator
+	strDateSeparator = GetDateSeparator();
+	strTimeSeparator = GetTimeSeparator();
+	strDecimalSeparator = GetDecimalSeparator();
+
 	for (;;) {
 		DialogBuilder Builder(Msg::ConfigInterfaceTitle, L"InterfSettings");
 
@@ -309,6 +332,53 @@ void InterfaceSettings()
 		Builder.AddCheckbox(Msg::ConfigDeleteTotal, &Opt.DelOpt.DelShowTotal);
 		Builder.AddCheckbox(Msg::ConfigPgUpChangeDisk, &Opt.PgUpChangeDisk);
 
+		Builder.AddSeparator(Msg::ConfigDateFormat);
+
+		/*DialogBuilderListItem CAListItems[] = {
+				{Msg::ConfigDateFormatMDY, 0},
+				{Msg::ConfigDateFormatDMY, 1},
+				{Msg::ConfigDateFormatYMD, 2},
+		};
+		DialogItemEx *DateFormatComboBox = Builder.AddComboBox((int *)&DateFormatIndex, 10,
+				CAListItems, ARRAYSIZE(CAListItems),
+				DIF_DROPDOWNLIST | DIF_LISTAUTOHIGHLIGHT | DIF_LISTWRAPMODE);
+		DialogItemEx *DateFormatText = Builder.AddTextAfter(DateFormatComboBox, Msg::ConfigDateFormat);
+		DateFormatText->Indent(1);
+		*/
+		static FarLangMsg DateFormatOptions[] = {Msg::ConfigDateFormatMDY, Msg::ConfigDateFormatDMY,
+				Msg::ConfigDateFormatYMD};
+		Builder.AddRadioButtonsHorz(&DateFormatIndex, ARRAYSIZE(DateFormatOptions), DateFormatOptions);
+
+		Builder.StartColumns();
+		DialogItemEx *DateSeparatorEdit = Builder.AddEditField(&strDateSeparator, 0);
+		DateSeparatorEdit->Type = DI_FIXEDIT;
+		DateSeparatorEdit->Flags |= DIF_MASKEDIT;
+		DateSeparatorEdit->strMask = L"X";
+		Builder.AddTextAfter(DateSeparatorEdit, Msg::ConfigDateSeparator);
+
+		DialogItemEx *TimeSeparatorEdit = Builder.AddEditField(&strTimeSeparator, 0);
+		TimeSeparatorEdit->Type = DI_FIXEDIT;
+		TimeSeparatorEdit->Flags |= DIF_MASKEDIT;
+		TimeSeparatorEdit->strMask = L"X";
+		Builder.AddTextAfter(TimeSeparatorEdit, Msg::ConfigTimeSeparator);
+
+		DialogItemEx *DecimalSeparatorEdit = Builder.AddEditField(&strDecimalSeparator, 0);
+		DecimalSeparatorEdit->Type = DI_FIXEDIT;
+		DecimalSeparatorEdit->Flags |= DIF_MASKEDIT;
+		DecimalSeparatorEdit->strMask = L"X";
+		Builder.AddTextAfter(DecimalSeparatorEdit, Msg::ConfigDecimalSeparator);
+        
+		Builder.ColumnBreak();
+		int DateTimeDefaultID = -1;
+		Builder.AddButton(Msg::ConfigDateTimeDefault, DateTimeDefaultID);
+		int DateTimeCurrentID = -1;
+		Builder.AddButton(Msg::ConfigDateTimeCurrent, DateTimeCurrentID);
+		int DateTimeFromSystemID = -1;
+		Builder.AddButton(Msg::ConfigDateTimeFromSystem, DateTimeFromSystemID);
+		Builder.EndColumns();
+
+		Builder.AddSeparator();
+
 		const DWORD supported_tweaks = ApplyConsoleTweaks();
 		if (supported_tweaks & TWEAK_STATUS_SUPPORT_BLINK_RATE) {
 
@@ -353,23 +423,141 @@ void InterfaceSettings()
 			if (Opt.CMOpt.CopyTimeRule)
 				Opt.CMOpt.CopyTimeRule = 3;
 
+			Opt.DateFormat = DateFormatIndex;
+			Opt.strDateSeparator = strDateSeparator;
+			Opt.strTimeSeparator = strTimeSeparator;
+			Opt.strDecimalSeparator = strDecimalSeparator;
+			ConvertDate_ResetInit();
+
 			SetFarConsoleMode();
 			CtrlObject->Cp()->LeftPanel->Update(UPDATE_KEEP_SELECTION);
 			CtrlObject->Cp()->RightPanel->Update(UPDATE_KEEP_SELECTION);
 			CtrlObject->Cp()->SetScreenPosition();
 			// $ 10.07.2001 SKV ! надо это делать, иначе если кейбар спрятали, будет полный рамс.
 			CtrlObject->Cp()->Redraw();
+
 			ApplyConsoleTweaks();
+			WINPORT(SetConsoleCursorBlinkTime)(NULL, Opt.CursorBlinkTime);
 			break;
 		}
 
-		if (ChangeFontID == -1 || clicked_id != ChangeFontID)
+		if (ChangeFontID != -1 && clicked_id == ChangeFontID)
+			WINPORT(ConsoleChangeFont)();
+
+		else if (clicked_id == DateTimeDefaultID) {
+			DateFormatIndex = GetDateFormatDefault();
+			strDateSeparator = GetDateSeparatorDefault();
+			strTimeSeparator = GetTimeSeparatorDefault();
+			strDecimalSeparator = GetDecimalSeparatorDefault();
+		}
+
+		else if (clicked_id == DateTimeCurrentID) {
+			DateFormatIndex = GetDateFormat();
+			strDateSeparator = GetDateSeparator();
+			strTimeSeparator = GetTimeSeparator();
+			strDecimalSeparator = GetDecimalSeparator();
+		}
+
+		else if (clicked_id == DateTimeFromSystemID) {
+			// parcing part of possible https://help.gnome.org/users/gthumb/stable/gthumb-date-formats.html
+			std::string::size_type
+					pos_date_2 = std::string::npos,
+					pos_day = std::string::npos,
+					pos_month = std::string::npos,
+					pos_year = std::string::npos,
+					pos_time_2 = std::string::npos;
+			size_t length_decimal;
+			std::string format_date = nl_langinfo(D_FMT);
+			std::string format_time = nl_langinfo(T_FMT);
+			std::string format_decimal = nl_langinfo(RADIXCHAR/*DECIMAL_POINT*/);
+			if (format_date=="%D") { // %D Equivalent to %m/%d/%y
+				DateFormatIndex = 0;
+				strTimeSeparator = "/";
+				pos_date_2 = 0; // for not error in message
+			}
+			if (format_date=="%F") { // %F Equivalent to %Y-%m-%d
+				DateFormatIndex = 2;
+				strTimeSeparator = "-";
+				pos_date_2 = 0; // for not error in message
+			}
+			else if (format_date.length() >= 8) {
+				std::vector<const char*> codes_day = { "%d", "%e", "%Ed", "%Ee", "%Od", "%Oe" };
+				for (const auto &code : codes_day) {
+					pos_day = format_date.find(code);
+					if (pos_day != std::string::npos)
+						break;
+				}
+				std::vector<const char*> codes_month = {
+					"%m", "%B", "%b", "%h", "%Em", "%EB", "%Eb", "%Eh", "%Om", "%OB", "%Ob", "%Oh" };
+				for (const auto &code : codes_month) {
+					pos_month = format_date.find(code);
+					if (pos_month != std::string::npos)
+						break;
+				}
+				std::vector<const char*> codes_year = {
+					"%Y", "%y", "%G", "%g", "%EY", "%Ey", "%EG", "%Eg", "%OY", "%Oy", "%OG", "%Og" };
+				for (const auto &code : codes_year) {
+					pos_year = format_date.find(code);
+					if (pos_year != std::string::npos)
+						break;
+				}
+				if (pos_day != std::string::npos && pos_month != std::string::npos && pos_year != std::string::npos) {
+					if (pos_day < pos_month && pos_month < pos_year) // day-month-year
+					{ DateFormatIndex = 1; pos_date_2 = pos_month; }
+					else if (pos_year < pos_month && pos_month < pos_day) // year-month-day
+					{ DateFormatIndex = 2; pos_date_2 = pos_month; }
+					else if (pos_month < pos_day  && pos_month < pos_year) // month-day-year
+					{ DateFormatIndex = 0; pos_date_2 = pos_day; }
+				}
+			}
+			if (pos_date_2 != std::string::npos)
+				strDateSeparator = format_date[pos_date_2-1];
+
+			if (format_time=="%T") { // %T The time in 24-hour notation (%H:%M:%S).
+				strTimeSeparator = ":";
+				pos_time_2 = 0; // for not error in message
+			}
+			else {
+				pos_day = format_time.find("%");
+				if (pos_day != std::string::npos) {
+					pos_time_2 = format_time.find("%", pos_day+2);
+					if (pos_time_2 != std::string::npos)
+						strTimeSeparator = format_time[pos_time_2-1];
+				}
+			}
+
+			length_decimal = format_decimal.length();
+			if (length_decimal > 0)
+				strDecimalSeparator = format_decimal[0];
+
+			ExMessager em;
+			em.Add(L"From system locale");
+			em.AddFormat(L"Date format from locale:      \"%s\"", format_date.c_str());
+			em.AddFormat(L"  Date order:        %s (order %d)",
+				(pos_date_2 != std::string::npos) ? "imported" : "did not changed",
+				DateFormatIndex);
+			em.AddFormat(L"  Date separator:    %s (\'%ls\')",
+				(pos_date_2 != std::string::npos) ? "imported" : "did not changed",
+				strDateSeparator.CPtr());
+			em.AddFormat(L"Time format from locale:      \"%s\"", format_time.c_str());
+			em.AddFormat(L"  Time separator:    %s (\'%ls\')",
+				(pos_time_2 != std::string::npos) ? "imported" : "did not changed",
+				 strTimeSeparator.CPtr());
+			em.AddFormat(L"DecimalSeparator from locale: \"%s\"", format_decimal.c_str());
+			em.AddFormat(L"  Decimal separator: %s (\'%ls\')",
+				length_decimal>0 ? "imported" : "did not changed",
+				strDecimalSeparator.CPtr());
+			em.Add(Msg::Ok);
+			em.Show(MSG_LEFTALIGN |
+					( (pos_date_2 == std::string::npos
+						|| pos_time_2 == std::string::npos
+						|| length_decimal<=0 )
+					? MSG_WARNING : 0),
+				1);
+		}
+		else
 			break;
-
-		WINPORT(ConsoleChangeFont)();
 	}
-
-	WINPORT(SetConsoleCursorBlinkTime)(NULL, Opt.CursorBlinkTime);
 }
 
 void AutoCompleteSettings()
@@ -437,6 +625,9 @@ void VMenuSettings()
 	Builder.AddText(Msg::ConfigVMenuMBtnClick);
 	Builder.AddComboBox((int *)&Opt.VMenu.MBtnClick, 40, CAListItems, ARRAYSIZE(CAListItems),
 			DIF_DROPDOWNLIST | DIF_LISTAUTOHIGHLIGHT | DIF_LISTWRAPMODE);
+
+	Builder.AddCheckbox(Msg::ConfigVMenuStopEdge, (BOOL *)&Opt.VMenu.MenuLoopScroll);
+
 	Builder.AddOKCancel();
 	Builder.ShowDialog();
 }
