@@ -276,6 +276,7 @@ struct VMenuOptions
 	int LBtnClick;
 	int RBtnClick;
 	int MBtnClick;
+	bool MenuLoopScroll;
 };
 
 struct CommandLineOptions
@@ -326,6 +327,7 @@ struct FindFileOptions
 	int FileSearchMode;
 	bool FindFolders;
 	bool FindSymLinks;
+	bool FindCaseSensitiveFileMask;
 	bool CollectFiles;
 	bool UseFilter;
 	bool FindAlternateStreams;
@@ -408,6 +410,7 @@ struct Options
 	int RightSelectedFirst;
 	int LeftSelectedFirst;
 	int SelectFolders;
+	int PanelCaseSensitiveCompareSelect;
 	int ReverseSort;
 	int SortFolderExt;
 	int DeleteToRecycleBin;				// удалять в корзину?
@@ -461,8 +464,11 @@ struct Options
 	int SavePluginFoldersHistory;
 	int FoldersHistoryCount;
 	int DialogsHistoryCount;
+	int HistoryRemoveDupsRule;
+	int AutoHighlightHistory;
 
 	BYTE HistoryShowTimes[8];
+	DWORD HistoryDirsPrefixLen;
 
 	FindFileOptions FindOpt;
 
@@ -616,6 +622,11 @@ struct Options
 	bool IsUserAdmin;
 	FARString strWindowTitle;
 
+	int DateFormat;
+	FARString strDateSeparator;
+	FARString strTimeSeparator;
+	FARString strDecimalSeparator;
+
 	bool IsFirstStart;
 
 	std::vector<std::wstring> CmdLineStrings;
