@@ -77,15 +77,24 @@ private:
 	void ChangeDirFromHistory(bool PluginPath, int SelectType, FARString strDir, FARString strFile=L"");
 	void CheckForKeyPressAfterCmd(int r);
 
+	void ProcessKey_ClearTerminalHistory();
+	void ProcessKey_ShowFolderTree();
+	void ProcessKey_ShowFolderHistory();
+	void ProcessKey_ShowCommandsHistory();
+	int ProcessKey_Enter(FarKey Key);
+	int ProcessKeyIfVisible(FarKey Key);
+
 public:
 	CommandLine();
 	virtual ~CommandLine();
+	void SetVisible(bool Visible);
 
 public:
 	virtual int ProcessKey(FarKey Key);
 	virtual int ProcessMouse(MOUSE_EVENT_RECORD *MouseEvent);
 	virtual int64_t VMProcess(MacroOpcode OpCode, void *vParam = nullptr, int64_t iParam = 0);
 
+	virtual void Show();
 	virtual void ResizeConsole();
 
 	std::string GetConsoleLog(HANDLE con_hnd, bool colored);
@@ -131,3 +140,9 @@ public:
 
 	void RedrawWithoutComboBoxMark();
 };
+
+struct CmdLineVisibleScope
+{
+	CmdLineVisibleScope();
+	~CmdLineVisibleScope();
+};
