@@ -192,7 +192,7 @@ void ToggleVideoMode()
 	WINPORT(SetConsoleWindowMaximized)(LargestSize.X != CurSize.X || LargestSize.Y != CurSize.Y);
 }
 
-void GenerateWINDOW_BUFFER_SIZE_EVENT(int Sx, int Sy)
+void GenerateWINDOW_BUFFER_SIZE_EVENT(int Sx, int Sy, bool Damaged)
 {
 	COORD Size;
 	if (Sx == -1 || Sy == -1) {
@@ -202,6 +202,7 @@ void GenerateWINDOW_BUFFER_SIZE_EVENT(int Sx, int Sy)
 	Rec.EventType = WINDOW_BUFFER_SIZE_EVENT;
 	Rec.Event.WindowBufferSizeEvent.dwSize.X = Sx == -1 ? Size.X : Sx;
 	Rec.Event.WindowBufferSizeEvent.dwSize.Y = Sy == -1 ? Size.Y : Sy;
+	Rec.Event.WindowBufferSizeEvent.bDamaged = Damaged ? TRUE : FALSE;
 	DWORD Writes;
 	Console.WriteInput(Rec, 1, Writes);
 }
@@ -308,9 +309,9 @@ void ShowTime(int ShowAlways)
 
 	if (CurFrame) {
 		int ModType = CurFrame->GetType();
-		SetColor(ModType == MODALTYPE_VIEWER
+		SetColor(FarColorToReal(ModType == MODALTYPE_VIEWER
 						? COL_VIEWERCLOCK
-						: (ModType == MODALTYPE_EDITOR ? COL_EDITORCLOCK : COL_CLOCK));
+						: (ModType == MODALTYPE_EDITOR ? COL_EDITORCLOCK : COL_CLOCK)));
 		Text(strClockText);
 		// ScrBuf.Flush();
 	}
@@ -488,7 +489,7 @@ void InitRecodeOutTable()
 	//_SVS(SysLogDump("Oem2Unicode",0,(LPBYTE)Oem2Unicode,sizeof(Oem2Unicode),nullptr));
 }
 
-void Text64(int X, int Y, uint64_t Color, const WCHAR *Str, size_t Length)
+void Text(int X, int Y, uint64_t Color, const WCHAR *Str, size_t Length)
 {
 	CurColor = Color;
 	CurX = X;
@@ -496,9 +497,9 @@ void Text64(int X, int Y, uint64_t Color, const WCHAR *Str, size_t Length)
 	Text(Str, Length);
 }
 
-void Text(int X, int Y, int Color, const WCHAR *Str)
+void Text(int X, int Y, uint64_t Color, const WCHAR *Str)
 {
-	CurColor = FarColorToReal(Color);
+	CurColor = Color;
 	CurX = X;
 	CurY = Y;
 	Text(Str);
@@ -546,6 +547,54 @@ void Text(const WCHAR *Str, size_t Length)
 	CurX+= nCells;
 }
 
+void TextEx(const WCHAR *Str, size_t Length)
+{
+	if (Length == (size_t)-1)
+		Length = StrLength(Str);
+
+	if (Length == 0)
+		return;
+
+	CHAR_INFO StackBuffer[StackBufferSize];
+	PCHAR_INFO HeapBuffer = nullptr;
+	PCHAR_INFO BufPtr = StackBuffer;
+
+	if (Length * 2 >= StackBufferSize) {
+		HeapBuffer = new CHAR_INFO[Length * 2 + 1];
+		BufPtr = HeapBuffer;
+	}
+
+	int nCells = 0;
+	std::wstring wstr;
+	for (size_t i = 0; i < Length; ++nCells) {
+
+		const size_t nG = StrSizeOfCell(&Str[i], Length - i);
+
+		if (nG > 1) {
+			wstr.assign(&Str[i], nG);
+			CI_SET_COMPOSITE(BufPtr[nCells], wstr.c_str());
+			CI_SET_ATTR(BufPtr[nCells], CurColor);
+		} else {
+			CI_SET_WCHAR(BufPtr[nCells], Str[i]);
+			CI_SET_ATTR(BufPtr[nCells], CurColor & (0xFFFFFFFFFFFFFFFF ^ (COMMON_LVB_STRIKEOUT | COMMON_LVB_UNDERSCORE)) );
+		}
+
+//		CI_SET_ATTR(BufPtr[nCells], CurColor);
+
+		if (IsCharFullWidth(Str[i])) {
+			++nCells;
+			CI_SET_WCATTR(BufPtr[nCells], 0, CurColor);
+		}
+		i+= nG;
+	}
+
+	ScrBuf.Write(CurX, CurY, BufPtr, nCells);
+	if (HeapBuffer) {
+		delete[] HeapBuffer;
+	}
+	CurX+= nCells;
+}
+
 void Text(FarLangMsg MsgId)
 {
 	Text(MsgId.CPtr());
@@ -570,10 +619,10 @@ void VText(const WCHAR *Str)
 	}
 }
 
-void HiText(const wchar_t *Str, DWORD64 HiColor, int isVertText)
+void HiText(const wchar_t *Str, uint64_t HiColor, int isVertText)
 {
 	FARString strTextStr;
-	DWORD64 SaveColor;
+	uint64_t SaveColor;
 	size_t pos;
 	strTextStr = Str;
 
@@ -639,7 +688,7 @@ void HiText(const wchar_t *Str, DWORD64 HiColor, int isVertText)
 	}
 }
 
-void SetScreen(int X1, int Y1, int X2, int Y2, wchar_t Ch, int Color)
+void SetScreen(int X1, int Y1, int X2, int Y2, wchar_t Ch, uint64_t Color)
 {
 	if (X1 < 0)
 		X1 = 0;
@@ -653,10 +702,10 @@ void SetScreen(int X1, int Y1, int X2, int Y2, wchar_t Ch, int Color)
 	if (Y2 > ScrY)
 		Y2 = ScrY;
 
-	ScrBuf.FillRect(X1, Y1, X2, Y2, Ch, FarColorToReal(Color));
+	ScrBuf.FillRect(X1, Y1, X2, Y2, Ch, Color);
 }
 
-void MakeShadow(int X1, int Y1, int X2, int Y2)
+void MakeShadow(int X1, int Y1, int X2, int Y2, SaveScreen *ss)
 {
 	if (X1 < 0)
 		X1 = 0;
@@ -670,10 +719,11 @@ void MakeShadow(int X1, int Y1, int X2, int Y2)
 	if (Y2 > ScrY)
 		Y2 = ScrY;
 
-	ScrBuf.ApplyColorMask(X1, Y1, X2, Y2, 0xF8);
+//	ScrBuf.ApplyColorMask(X1, Y1, X2, Y2, 0xFFFFFFFFFFFFFFF8);
+	ScrBuf.ApplyShadow(X1, Y1, X2, Y2, ss);
 }
 
-void ChangeBlockColor(int X1, int Y1, int X2, int Y2, int Color)
+void ChangeBlockColor(int X1, int Y1, int X2, int Y2, uint64_t Color)
 {
 	if (X1 < 0)
 		X1 = 0;
@@ -687,7 +737,7 @@ void ChangeBlockColor(int X1, int Y1, int X2, int Y2, int Color)
 	if (Y2 > ScrY)
 		Y2 = ScrY;
 
-	ScrBuf.ApplyColor(X1, Y1, X2, Y2, FarColorToReal(Color));
+	ScrBuf.ApplyColor(X1, Y1, X2, Y2, Color);
 }
 
 void mprintf(const wchar_t *fmt, ...)
@@ -710,34 +760,19 @@ void vmprintf(const wchar_t *fmt, ...)
 	va_end(argptr);
 }
 
-void SetColor(DWORD64 Color, bool ApplyToConsole)
+void SetColor(uint64_t Color, bool ApplyToConsole)
 {
-	CurColor = FarColorToReal(Color & 0xffff);
+	CurColor = Color;
 
-	if (Color & 0xffffff0000000000) {
-		CurColor|= BACKGROUND_TRUECOLOR;
-		CurColor|= (Color & 0xffffff0000000000);
-	}
-	if (Color & 0x000000ffffff0000) {
-		CurColor|= FOREGROUND_TRUECOLOR;
-		CurColor|= (Color & 0x000000ffffff0000);
-	}
 	if (ApplyToConsole) {
 		Console.SetTextAttributes(CurColor);
 	}
 }
 
-void SetColor64(DWORD64 Color, bool ApplyToConsole)
+void SetFarColor(uint16_t Color, bool ApplyToConsole)
 {
-	CurColor = Color;
-/**
-	if (Color & 0xffffff0000000000) {
-		CurColor |= BACKGROUND_TRUECOLOR;
-	}
-	if (Color & 0x000000ffffff0000) {
-		CurColor |= FOREGROUND_TRUECOLOR;
-	}
-**/
+	CurColor = FarColorToReal(Color);
+
 	if (ApplyToConsole) {
 		Console.SetTextAttributes(CurColor);
 	}
@@ -789,31 +824,18 @@ void ComposeAndSetColor(WORD BaseColor, const FarTrueColorForeAndBack *TrueColor
 	}
 }
 
-void SetRealColor(DWORD64 wAttributes, bool ApplyToConsole)
+void ClearScreen(uint64_t Color)
 {
-	CurColor = wAttributes;
-	if (ApplyToConsole) {
-		Console.SetTextAttributes(CurColor);
-	}
-}
-
-DWORD64 GetRealColor()
-{
-	return CurColor;
-}
-
-void ClearScreen(int Color)
-{
-	Color = FarColorToReal(Color);
+	SetColor(Color);
 	ScrBuf.FillRect(0, 0, ScrX, ScrY, L' ', Color);
 	ScrBuf.ResetShadow();
 	ScrBuf.Flush();
 	Console.SetTextAttributes(Color);
 }
 
-DWORD64 GetColor()
+uint64_t GetColor()
 {
-	return (CurColor);
+	return CurColor;
 }
 
 void ScrollScreen(int Count)
@@ -854,12 +876,13 @@ void BoxText(const wchar_t *Str, int IsVert)
 /*
 	Отрисовка прямоугольника.
 */
-void Box(int x1, int y1, int x2, int y2, int Color, int Type)
+void Box(int x1, int y1, int x2, int y2, uint64_t Color, int Type)
 {
 	if (x1 >= x2 || y1 >= y2)
 		return;
 
-	SetColor(Color);
+//	SetColor(Color);
+	CurColor = Color;
 	Type = (Type == DOUBLE_BOX || Type == SHORT_DOUBLE_BOX);
 
 	WCHAR StackBuffer[StackBufferSize];
