@@ -1491,14 +1491,6 @@ int FileEditor::LoadFile(const wchar_t *Name, int &UserBreak)
 		if (CurTime - StartTime > RedrawTimeout) {
 			StartTime = CurTime;
 
-			if (CheckForEscSilent()) {
-				if (ConfirmAbortOp()) {
-					UserBreak = 1;
-					EditFile.Close();
-					return FALSE;
-				}
-			}
-
 			SetCursorType(FALSE, 0);
 			INT64 CurPos = 0;
 			EditFile.GetPointer(CurPos);
@@ -1513,6 +1505,14 @@ int FileEditor::LoadFile(const wchar_t *Name, int &UserBreak)
 				}
 			}
 			Editor::EditorShowMsg(Msg::EditTitle, Msg::EditReading, Name, Percent);
+
+			if (CheckForEscSilent()) {
+				if (ConfirmAbortOp()) {
+					UserBreak = 1;
+					EditFile.Close();
+					return FALSE;
+				}
+			}
 		}
 
 		const wchar_t *CurEOL;
@@ -2234,7 +2234,7 @@ void FileEditor::ShowStatus()
 	if (m_editor->Locked() || !TitleBarVisible)
 		return;
 
-	SetColor(COL_EDITORSTATUS);
+	SetFarColor(COL_EDITORSTATUS);
 	GotoXY(X1, Y1);		//??
 	FARString strLineStr;
 	FARString strLocalTitle;
@@ -2310,7 +2310,7 @@ void FileEditor::ShowStatus()
 
 	if (Opt.ViewerEditorClock && Flags.Check(FFILEEDIT_FULLSCREEN)) {
 		if (X2 > 5) {
-			Text(X2 - 5, Y1, COL_EDITORTEXT, L" ");
+			Text(X2 - 5, Y1, FarColorToReal(COL_EDITORTEXT), L" ");
 		}
 		ShowTime(FALSE);
 	}
