@@ -214,6 +214,51 @@ FilePanels::~FilePanels()
 	RightPanel = nullptr;
 }
 
+void FilePanels::UpdateCmdLineVisibility(bool repos)
+{
+	int left_x1, left_x2, left_y1, left_y2;
+	int right_x1, right_x2, right_y1, right_y2;
+	int cl_x1, cl_x2, cl_y;
+	bool cl_visible = CtrlObject->CmdLine->IsVisible();
+
+	LeftPanel->GetPosition(left_x1, left_y1, left_x2, left_y2);
+	RightPanel->GetPosition(right_x1, right_y1, right_x2, right_y2);
+	CtrlObject->CmdLine->GetPosition(cl_x1, cl_y, cl_x2, cl_y);
+
+	const bool left_overlap = LeftPanel->IsVisible() && left_y2 + Opt.ShowKeyBar >= ScrY;
+	const bool right_overlap = RightPanel->IsVisible() && right_y2 + Opt.ShowKeyBar >= ScrY;
+	const bool new_cl_visible = !left_overlap || !right_overlap;
+
+	int new_cl_x1 = 0, new_cl_x2 = ScrX - 1, new_cl_y = ScrY - (Opt.ShowKeyBar);
+	if (new_cl_visible) {
+		if (left_overlap) {
+			new_cl_x1 = right_x1;
+		} else if (right_overlap) {
+			new_cl_x2 = left_x2 - 1;
+		}
+	}
+	if (new_cl_x1 != cl_x1 || new_cl_x2 != cl_x2 || new_cl_y != cl_y) {
+		repos = true;
+	}
+	if (cl_visible != new_cl_visible) {
+		CtrlObject->CmdLine->SetVisible(new_cl_visible);
+	}
+	if (repos) {
+		CtrlObject->CmdLine->SetPosition(new_cl_x1, new_cl_y, new_cl_x2, new_cl_y);
+	}
+	if (cl_visible != new_cl_visible || repos) {
+		if (new_cl_visible) {
+			CtrlObject->CmdLine->Redraw();
+		}
+		if (LeftPanel->IsVisible()) {
+			LeftPanel->Redraw();
+		}
+		if (RightPanel->IsVisible()) {
+			RightPanel->Redraw();
+		}
+	}
+}
+
 void FilePanels::SetPanelPositions(int LeftFullScreen, int RightFullScreen)
 {
 	if (Opt.WidthDecrement < -(ScrX / 2 - 10))
@@ -222,32 +267,32 @@ void FilePanels::SetPanelPositions(int LeftFullScreen, int RightFullScreen)
 	if (Opt.WidthDecrement > (ScrX / 2 - 10))
 		Opt.WidthDecrement = (ScrX / 2 - 10);
 
-	Opt.LeftHeightDecrement = Max(0, Min(Opt.LeftHeightDecrement, ScrY - 7));
-	Opt.RightHeightDecrement = Max(0, Min(Opt.RightHeightDecrement, ScrY - 7));
+	Opt.LeftHeightDecrement = Max(-1, Min(Opt.LeftHeightDecrement, ScrY - 7));
+	Opt.RightHeightDecrement = Max(-1, Min(Opt.RightHeightDecrement, ScrY - 7));
+
+	const int LeftY2 = ScrY - 1 - (Opt.ShowKeyBar) - Opt.LeftHeightDecrement;
+	const int RightY2 = ScrY - 1 - (Opt.ShowKeyBar) - Opt.RightHeightDecrement;
 
 	if (LeftFullScreen) {
-		LeftPanel->SetPosition(0, Opt.ShowMenuBar ? 1 : 0, ScrX,
-				ScrY - 1 - (Opt.ShowKeyBar) - Opt.LeftHeightDecrement);
+		LeftPanel->SetPosition(0, Opt.ShowMenuBar ? 1 : 0, ScrX, LeftY2);
 		LeftPanel->ViewSettings.FullScreen = 1;
 	} else {
-		LeftPanel->SetPosition(0, Opt.ShowMenuBar ? 1 : 0, ScrX / 2 - Opt.WidthDecrement,
-				ScrY - 1 - (Opt.ShowKeyBar) - Opt.LeftHeightDecrement);
+		LeftPanel->SetPosition(0, Opt.ShowMenuBar ? 1 : 0, ScrX / 2 - Opt.WidthDecrement, LeftY2);
 	}
 
 	if (RightFullScreen) {
-		RightPanel->SetPosition(0, Opt.ShowMenuBar ? 1 : 0, ScrX,
-				ScrY - 1 - (Opt.ShowKeyBar) - Opt.RightHeightDecrement);
+		RightPanel->SetPosition(0, Opt.ShowMenuBar ? 1 : 0, ScrX, RightY2);
 		RightPanel->ViewSettings.FullScreen = 1;
 	} else {
-		RightPanel->SetPosition(ScrX / 2 + 1 - Opt.WidthDecrement, Opt.ShowMenuBar ? 1 : 0, ScrX,
-				ScrY - 1 - (Opt.ShowKeyBar) - Opt.RightHeightDecrement);
+		RightPanel->SetPosition(ScrX / 2 + 1 - Opt.WidthDecrement, Opt.ShowMenuBar ? 1 : 0, ScrX, RightY2);
 	}
+
+	UpdateCmdLineVisibility(true);
 }
 
 void FilePanels::SetScreenPosition()
 {
 	_OT(SysLog(L"[%p] FilePanels::SetScreenPosition() {%d, %d - %d, %d}", this, X1, Y1, X2, Y2));
-	CtrlObject->CmdLine->SetPosition(0, ScrY - (Opt.ShowKeyBar), ScrX - 1, ScrY - (Opt.ShowKeyBar));
 	TopMenuBar.SetPosition(0, 0, ScrX, 0);
 	MainKeyBar.SetPosition(0, ScrY, ScrX, ScrY);
 	SetPanelPositions(LeftPanel->IsFullScreen(), RightPanel->IsFullScreen());
@@ -367,8 +412,7 @@ int FilePanels::ProcessKey(FarKey Key)
 
 	if ((Key == KEY_CTRLLEFT || Key == KEY_CTRLRIGHT || Key == KEY_CTRLNUMPAD4 || Key == KEY_CTRLNUMPAD6
 				/* || Key==KEY_CTRLUP || Key==KEY_CTRLDOWN || Key==KEY_CTRLNUMPAD8 || Key==KEY_CTRLNUMPAD2 */)
-			&& (CtrlObject->CmdLine->GetLength() > 0
-					|| (!LeftPanel->IsVisible() && !RightPanel->IsVisible()))) {
+			&& (CtrlObject->CmdLine->GetLength() > 0 || (!LeftPanel->IsVisible() && !RightPanel->IsVisible()))) {
 		CtrlObject->CmdLine->ProcessKey(Key);
 		return TRUE;
 	}
@@ -401,7 +445,7 @@ int FilePanels::ProcessKey(FarKey Key)
 
 				LeftPanel->Show();
 			}
-
+			UpdateCmdLineVisibility();
 			Redraw();
 			break;
 		}
@@ -417,7 +461,7 @@ int FilePanels::ProcessKey(FarKey Key)
 
 				RightPanel->Show();
 			}
-
+			UpdateCmdLineVisibility();
 			Redraw();
 			break;
 		}
@@ -508,6 +552,7 @@ int FilePanels::ProcessKey(FarKey Key)
 							RightPanel->SetFocus();
 					}
 				}
+				UpdateCmdLineVisibility();
 			}
 			break;
 		}
@@ -519,7 +564,7 @@ int FilePanels::ProcessKey(FarKey Key)
 					AnotherPanel->Hide();
 				else
 					AnotherPanel->Show();
-
+				UpdateCmdLineVisibility();
 				CtrlObject->CmdLine->Redraw();
 			}
 
@@ -531,9 +576,9 @@ int FilePanels::ProcessKey(FarKey Key)
 			return TRUE;
 		}
 		case KEY_CTRLU: {
-			if (!LeftPanel->IsVisible() && !RightPanel->IsVisible())
+			if (!LeftPanel->IsVisible() && !RightPanel->IsVisible()) {
 				CtrlObject->CmdLine->ProcessKey(Key);
-			else
+			} else
 				SwapPanels();
 
 			break;
@@ -586,11 +631,11 @@ int FilePanels::ProcessKey(FarKey Key)
 		case KEY_CTRLDOWN:
 		case KEY_CTRLNUMPAD2: {
 			bool Set = false;
-			if (Opt.LeftHeightDecrement > 0) {
+			if (Opt.LeftHeightDecrement >= 0) {
 				Opt.LeftHeightDecrement--;
 				Set = true;
 			}
-			if (Opt.RightHeightDecrement > 0) {
+			if (Opt.RightHeightDecrement >= 0) {
 				Opt.RightHeightDecrement--;
 				Set = true;
 			}
@@ -618,7 +663,7 @@ int FilePanels::ProcessKey(FarKey Key)
 		case KEY_CTRLSHIFTNUMPAD2: {
 			int &HeightDecrement =
 					(ActivePanel == LeftPanel) ? Opt.LeftHeightDecrement : Opt.RightHeightDecrement;
-			if (HeightDecrement > 0) {
+			if (HeightDecrement >= 0) {
 				HeightDecrement--;
 				SetScreenPosition();
 				FrameManager->RefreshFrame();
@@ -991,10 +1036,10 @@ void FilePanels::ShowConsoleTitle()
 void FilePanels::ResizeConsole()
 {
 	Frame::ResizeConsole();
-	CtrlObject->CmdLine->ResizeConsole();
 	MainKeyBar.ResizeConsole();
 	TopMenuBar.ResizeConsole();
 	SetScreenPosition();
+	CtrlObject->CmdLine->ResizeConsole();
 	_OT(SysLog(L"[%p] FilePanels::ResizeConsole() {%d, %d - %d, %d}", this, X1, Y1, X2, Y2));
 }
 
