@@ -400,9 +400,11 @@ enum FINDASKDLG
 	FAD_TEXT_CP,
 	FAD_COMBOBOX_CP,
 	FAD_SEPARATOR1,
+	FAD_CHECKBOX_CASEMASK,
 	FAD_CHECKBOX_CASE,
 	FAD_CHECKBOX_WHOLEWORDS,
 	FAD_CHECKBOX_HEX,
+	FAD_CHECKBOX_FILTER,
 	FAD_CHECKBOX_ARC,
 	FAD_CHECKBOX_DIRS,
 	FAD_CHECKBOX_LINKS,
@@ -410,7 +412,6 @@ enum FINDASKDLG
 	FAD_SEPARATOR_3,
 	FAD_TEXT_WHERE,
 	FAD_COMBOBOX_WHERE,
-	FAD_CHECKBOX_FILTER,
 	FAD_SEPARATOR_4,
 	FAD_BUTTON_FIND,
 	FAD_BUTTON_DRIVE,
@@ -863,8 +864,7 @@ static LONG_PTR WINAPI MainDlgProc(HANDLE hDlg, int Msg, int Param1, LONG_PTR Pa
 							if (!(Item.Item.Flags & LIF_SEPARATOR) && SelectedCodePage
 									&& Position.SelectPos > 1) {
 								// Преобразуем номер таблицы символов к строке
-								const std::string &strCodePageName = StrPrintf("%u", SelectedCodePage);
-								// strCodePageName.Format(L"%u", SelectedCodePage);
+								const std::string &strCodePageName = ToDec(SelectedCodePage);
 								//  Получаем текущее состояние флага в реестре
 								int SelectType =
 										ConfigReader(FavoriteCodePagesKey).GetInt(strCodePageName, 0);
@@ -1035,7 +1035,9 @@ static bool ScanFileByMapping(const char *Name)
 		for (UINT LastPercents = 0;;) {
 			const bool FirstFragment = (FilePos == 0);
 			const bool LastFragment = (FilePos + off_t(smm.Length()) >= FileSize);
-			if (findPattern->FindMatch(View, Length, FirstFragment, LastFragment).first != (size_t)-1) {
+			const size_t AnalyzeLength = LastFragment
+				? Length - (FilePos + off_t(smm.Length()) - FileSize) : Length;
+			if (findPattern->FindMatch(View, AnalyzeLength, FirstFragment, LastFragment).first != (size_t)-1) {
 				return true;
 			}
 			if (LastFragment) {
@@ -1136,7 +1138,8 @@ static void AnalyzeFileItem(HANDLE hDlg, PluginPanelItem *FileItem, const wchar_
 		return;
 	if ((FindData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0 && !Opt.FindOpt.FindFolders)
 		return;
-	if (!FileMaskForFindFile.Compare(FileName))
+
+	if (!FileMaskForFindFile.Compare(FileName, !Opt.FindOpt.FindCaseSensitiveFileMask))
 		return;
 
 	size_t ArcIndex = itd.GetFindFileArcIndex();
@@ -1380,7 +1383,7 @@ static LONG_PTR WINAPI FindDlgProc(HANDLE hDlg, int Msg, int Param1, LONG_PTR Pa
 						PauseFlag = true;
 						bool LocalRes = true;
 						if (Opt.Confirm.Esc)
-							LocalRes = AbortMessage() != 0;
+							LocalRes = AbortMessage();
 						PauseFlag = false;
 						if (LocalRes) {
 							StopFlag = true;
@@ -1672,9 +1675,19 @@ static LONG_PTR WINAPI FindDlgProc(HANDLE hDlg, int Msg, int Param1, LONG_PTR Pa
 								{
 									FileHolderPtr TFH;
 									if (FindItem.ArcIndex != LIST_INDEX_NONE) {
-										TFH = std::make_shared<FindDlg_TempFileHolder>(strSearchFileName,
-												FindItem.ArcIndex, FindItem.FindData);
+										ARCLIST ArcItem;
+										itd.GetArcListItem(FindItem.ArcIndex, ArcItem);
+										if (!(ArcItem.Flags & OPIF_REALNAMES)) { // check bug https://github.com/elfmz/far2l/issues/2223
+											//fprintf(stderr, "=== findfile: FindItem.ArcIndex != LIST_INDEX_NONE && !(ArcItem.Flags & OPIF_REALNAMES) => FindDlg_TempFileHolder\n");
+											TFH = std::make_shared<FindDlg_TempFileHolder>(strSearchFileName,
+													FindItem.ArcIndex, FindItem.FindData);
+										}
+										else {
+											//fprintf(stderr, "=== findfile: FindItem.ArcIndex != LIST_INDEX_NONE && (ArcItem.Flags & OPIF_REALNAMES) => FileHolder\n");
+											TFH = std::make_shared<FileHolder>(strSearchFileName);
+										}
 									} else {
+										//fprintf(stderr, "=== findfile: FindItem.ArcIndex == LIST_INDEX_NONE => FileHolder\n");
 										TFH = std::make_shared<FileHolder>(strSearchFileName);
 									}
 									FileEditor ShellEditor(TFH, CP_AUTODETECT, 0);
@@ -2703,29 +2716,30 @@ FindFiles::FindFiles()
 		const wchar_t *MasksHistoryName = L"Masks", *TextHistoryName = L"SearchText";
 		const wchar_t *HexMask = L"HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH HH";
 		const wchar_t VSeparator[] = {BoxSymbols[BS_T_H1V1], BoxSymbols[BS_V1], BoxSymbols[BS_V1],
-				BoxSymbols[BS_V1], BoxSymbols[BS_B_H1V1], 0};
+				BoxSymbols[BS_V1], BoxSymbols[BS_V1], BoxSymbols[BS_B_H1V1], 0};
 		struct DialogDataEx FindAskDlgData[] = {
 			{DI_DOUBLEBOX, 3,  1,  74, 18, {}, 0, Msg::FindFileTitle},
 			{DI_TEXT,      5,  2,  0,  2,  {}, 0, Msg::FindFileMasks},
 			{DI_EDIT,      5,  3,  72, 3,  {(DWORD_PTR)MasksHistoryName}, DIF_FOCUS | DIF_HISTORY | DIF_USELASTHISTORY,L""},
-			{DI_TEXT,      3,  4,  0,  4,  {}, DIF_SEPARATOR, L""},
-			{DI_TEXT,      5,  5,  0,  5,  {}, 0, L""},
+			{DI_TEXT,      3,  4,  0,  5,  {}, DIF_SEPARATOR, L""},
+			{DI_TEXT,      5,  5,  0,  6,  {}, 0, L""},
 			{DI_EDIT,      5,  6,  72, 6,  {(DWORD_PTR)TextHistoryName}, DIF_HISTORY, L""},
 			{DI_FIXEDIT,   5,  6,  72, 6,  {(DWORD_PTR)HexMask}, DIF_MASKEDIT, L""},
 			{DI_TEXT,      5,  7,  0,  7,  {}, 0, L""},
 			{DI_COMBOBOX,  5,  8,  72, 8,  {}, DIF_DROPDOWNLIST | DIF_LISTNOAMPERSAND, L""},
 			{DI_TEXT,      3,  9,  0,  9,  {}, DIF_SEPARATOR, L""},
-			{DI_CHECKBOX,  5,  10, 0,  10, {}, 0, Msg::FindFileCase},
-			{DI_CHECKBOX,  5,  11, 0,  11, {}, 0, Msg::FindFileWholeWords},
-			{DI_CHECKBOX,  5,  12, 0,  12, {}, 0, Msg::SearchForHex},
-			{DI_CHECKBOX,  40, 10, 0,  10, {}, 0, Msg::FindArchives},
-			{DI_CHECKBOX,  40, 11, 0,  11, {}, 0, Msg::FindFolders},
-			{DI_CHECKBOX,  40, 12, 0,  12, {}, 0, Msg::FindSymLinks},
-			{DI_TEXT,      3,  13, 0,  13, {}, DIF_SEPARATOR, L""},
-			{DI_VTEXT,     38, 9,  0,  9,  {}, DIF_BOXCOLOR, VSeparator},
-			{DI_TEXT,      5,  14, 0,  14, {}, 0, Msg::SearchWhere},
-			{DI_COMBOBOX,  5,  15, 36, 15, {}, DIF_DROPDOWNLIST | DIF_LISTNOAMPERSAND, L""},
-			{DI_CHECKBOX,  40, 15, 0,  15, {UseFilter ? BSTATE_CHECKED : BSTATE_UNCHECKED}, DIF_AUTOMATION, Msg::FindUseFilter},
+			{DI_CHECKBOX,  5,  10, 0,  10, {}, 0, Msg::FindFileCaseFileMask},
+			{DI_CHECKBOX,  5,  11, 0,  11, {}, 0, Msg::FindFileCase},
+			{DI_CHECKBOX,  5,  12, 0,  12, {}, 0, Msg::FindFileWholeWords},
+			{DI_CHECKBOX,  5,  13, 0,  13, {}, 0, Msg::SearchForHex},
+			{DI_CHECKBOX,  40, 10, 0,  10, {UseFilter ? BSTATE_CHECKED : BSTATE_UNCHECKED}, DIF_AUTOMATION, Msg::FindUseFilter},
+			{DI_CHECKBOX,  40, 11, 0,  11, {}, 0, Msg::FindArchives},
+			{DI_CHECKBOX,  40, 12, 0,  12, {}, 0, Msg::FindFolders},
+			{DI_CHECKBOX,  40, 13, 0,  13, {}, 0, Msg::FindSymLinks},
+			{DI_TEXT,      3,  14, 0,  14, {}, DIF_SEPARATOR, L""},
+			{DI_VTEXT,     38, 9,  0,   9, {}, DIF_BOXCOLOR, VSeparator},
+			{DI_TEXT,      5,  15, 37, 15, {}, 0, Msg::SearchWhere},
+			{DI_COMBOBOX,  38, 15, 72, 15, {}, DIF_DROPDOWNLIST | DIF_LISTNOAMPERSAND, L""},
 			{DI_TEXT,      3,  16, 0,  16, {}, DIF_SEPARATOR, L""},
 			{DI_BUTTON,    0,  17, 0,  17, {}, DIF_DEFAULT | DIF_CENTERGROUP, Msg::FindFileFind},
 			{DI_BUTTON,    0,  17, 0,  17, {}, DIF_CENTERGROUP, Msg::FindFileDrive},
@@ -2776,6 +2790,7 @@ FindFiles::FindFiles()
 			FindAskDlg[FAD_CHECKBOX_ARC].Selected = SearchInArchives;
 
 		FindAskDlg[FAD_EDIT_MASK].strData = strFindMask;
+		FindAskDlg[FAD_CHECKBOX_CASEMASK].Selected = Opt.FindOpt.FindCaseSensitiveFileMask;
 
 		if (SearchHex)
 			FindAskDlg[FAD_EDIT_HEX].strData = strFindStr;
@@ -2801,6 +2816,8 @@ FindFiles::FindFiles()
 			return;
 		}
 
+		Opt.FindOpt.FindCaseSensitiveFileMask = (FindAskDlg[FAD_CHECKBOX_CASEMASK].Selected == BSTATE_CHECKED);
+
 		Opt.FindCodePage = CodePage;
 		CmpCase = FindAskDlg[FAD_CHECKBOX_CASE].Selected;
 		WholeWords = FindAskDlg[FAD_CHECKBOX_WHOLEWORDS].Selected;
