@@ -192,7 +192,7 @@ FARString &EscapeSpace(FARString &strStr)
 static FARString unEscapeSpace(const wchar_t *str)
 {
 	if (*str == L'\0')
-		return "''";
+		return "";
 	FARString result;
 	for (const wchar_t *cur = str; *cur; ++cur) {
 		if (*cur == L'\\' && *(cur+1) != L'\\')
@@ -1175,7 +1175,8 @@ wchar_t GetDecimalSeparator()
 	// wchar_t Separator[4];
 	// GetLocaleInfo(LOCALE_USER_DEFAULT,LOCALE_SDECIMAL,Separator,ARRAYSIZE(Separator));
 	// return *Separator;
-	return L'.';
+	//return L'.';
+	return Opt.strDecimalSeparator.IsEmpty() ? GetDecimalSeparatorDefault() : Opt.strDecimalSeparator.At(0);
 }
 
 FARString
@@ -1231,7 +1232,7 @@ std::string EscapeUnprintable(const std::string &str)
 		unsigned char c = (unsigned char)*i;
 		if (c <= 0x20 || c > 0x7e || c == '\\') {
 			char buf[32];
-			sprintf(buf, "\\x%02x", c);
+			snprintf(buf, sizeof(buf), "\\x%02x", c);
 			out+= buf;
 		} else
 			out+= c;
