@@ -131,6 +131,8 @@ FARString FixedSizeStr(FARString str, size_t Cells, bool RAlign, bool TruncateCe
 void Transform(FARString &strBuffer, const wchar_t *ConvStr, wchar_t TransformType);
 
 wchar_t GetDecimalSeparator();
+inline const wchar_t GetDecimalSeparatorDefault() { return L'.'; };
+inline const wchar_t* GetDecimalSeparatorDefaultStr() { return L"."; };
 
 FARString
 ReplaceBrackets(const FARString &SearchStr, const FARString &ReplaceStr, RegExpMatch *Match, int Count);
