@@ -291,9 +291,9 @@ void FileList::ReadFileNames(int KeepSelection, int IgnoreVisible, int DrawMessa
 
 					if (!IsShowTitle) {
 						if (!DrawMessage) {
-							Text(X1 + 1, Y1, COL_PANELBOX, Title);
+							Text(X1 + 1, Y1, FarColorToReal(COL_PANELBOX), Title);
 							IsShowTitle = TRUE;
-							SetColor(Focus ? COL_PANELSELECTEDTITLE : COL_PANELTITLE);
+							SetFarColor(Focus ? COL_PANELSELECTEDTITLE : COL_PANELTITLE);
 						}
 					}
 
