@@ -125,6 +125,7 @@ void SetColors()
 		{(const wchar_t *)Msg::SetColorHelp,        0,             0},
 		{L"",                                       LIF_SEPARATOR, 0},
 		{(const wchar_t *)Msg::SetDefaultColors,    0,             0},
+		{(const wchar_t *)Msg::SetDefaultColorsRGB, 0,             0},
 		{(const wchar_t *)Msg::SetBW,               0,             0}
 	};
 	MenuDataEx PanelItems[] = {
@@ -329,14 +330,36 @@ void SetColors()
 			if ((GroupsCode = GroupsMenu.Modal::GetExitCode()) < 0)
 				break;
 
+			// Set default 8 bit colors
 			if (GroupsCode == 12) {
-				//                   было sizeof(Palette)
-				memcpy(Palette, DefaultPalette, SIZE_ARRAY_PALETTE);
+				for(size_t i = 0; i < SIZE_ARRAY_PALETTE; i++) {
+					Palette[i] = DefaultPalette8bit[i];
+				}
+
 				break;
 			}
 
+			// Set default RGB
 			if (GroupsCode == 13) {
-				memcpy(Palette, BlackPalette, SIZE_ARRAY_PALETTE);
+				uint32_t basepalette[32];
+				WINPORT(GetConsoleBasePalette)(NULL, basepalette);
+
+				for(size_t i = 0; i < SIZE_ARRAY_PALETTE; i++) {
+					uint8_t color = DefaultPalette8bit[i];
+					Palette[i] = ((uint64_t)basepalette[16 + (color & 0xF)] << 16);
+					Palette[i] += ((uint64_t)basepalette[color >> 4] << 40);
+					Palette[i] += FOREGROUND_TRUECOLOR + BACKGROUND_TRUECOLOR;
+					Palette[i] += color;
+				}
+
+				break;
+			}
+
+			// Set black & white 8 bit colors
+			if (GroupsCode == 14) {
+				for(size_t i = 0; i < SIZE_ARRAY_PALETTE; i++) {
+					Palette[i] = BlackPalette8bit[i];
+				}
 				break;
 			}
 
@@ -432,10 +455,12 @@ static void SetItemColors(MenuDataEx *Items, int *PaletteItems, int Size, int Ty
 void GetColor(int PaletteIndex)
 {
 	ChangeMacroMode chgMacroMode(MACRO_MENU);
-	uint16_t NewColor = Palette[PaletteIndex - COL_FIRSTPALETTECOLOR];
+	uint64_t NewColor = Palette[PaletteIndex];
+
+	if (GetColorDialog(&NewColor, false)) {
+		Palette[PaletteIndex] = NewColor;
+		Palette8bit[PaletteIndex] = static_cast<uint8_t>(NewColor);
 
-	if (GetColorDialog16(&NewColor, false)) {
-		Palette[PaletteIndex - COL_FIRSTPALETTECOLOR] = static_cast<uint16_t>(NewColor);
 		ScrBuf.Lock();	// отменяем всякую прорисовку
 		CtrlObject->Cp()->LeftPanel->Update(UPDATE_KEEP_SELECTION);
 		CtrlObject->Cp()->LeftPanel->Redraw();
