@@ -157,11 +157,11 @@ class VTShell : VTOutputReader::IProcessor, VTInputReader::IProcessor, IVTShell
 		// to avoid shell history pollution by far2l's intermediate script execution commands
 		const std::string &hc_override = VTSanitizeHistcontrol();
 
-		const BYTE col = FarColorToReal(COL_COMMANDLINEUSERSCREEN);
+		const BYTE col = static_cast<BYTE>(FarColorToReal(COL_COMMANDLINEUSERSCREEN));
 		char colorfgbg[32];
-		sprintf(colorfgbg, "%u;%u",
-			AnsiEsc::ConsoleColorToAnsi(col & 0xf),
-			AnsiEsc::ConsoleColorToAnsi((col >> 4) & 0xf));
+		snprintf(colorfgbg, sizeof(colorfgbg), "%u;%u",
+			 AnsiEsc::ConsoleColorToAnsi(col & 0xf),
+			 AnsiEsc::ConsoleColorToAnsi((col >> 4) & 0xf));
 
 		const auto color_bpp = WINPORT(GetConsoleColorPalette)(ConsoleHandle());
 		std::string askpass_app;
@@ -770,13 +770,13 @@ class VTShell : VTOutputReader::IProcessor, VTInputReader::IProcessor, IVTShell
 
 			if (_win32_input_mode_expected) {
 				char buffer[64];
-				sprintf(buffer, "\x1B[%i;%i;%i;%i;%i;%i_",
-						KeyEvent.wVirtualKeyCode,
-						KeyEvent.wVirtualScanCode,
-						KeyEvent.uChar.UnicodeChar,
-						KeyEvent.bKeyDown,
-						KeyEvent.dwControlKeyState,
-						KeyEvent.wRepeatCount
+				snprintf(buffer, sizeof(buffer), "\x1B[%i;%i;%i;%i;%i;%i_",
+						 KeyEvent.wVirtualKeyCode,
+						 KeyEvent.wVirtualScanCode,
+						 KeyEvent.uChar.UnicodeChar,
+						 KeyEvent.bKeyDown,
+						 KeyEvent.dwControlKeyState,
+						 KeyEvent.wRepeatCount
 					);
 				return buffer;
 			}
@@ -1013,8 +1013,8 @@ class VTShell : VTOutputReader::IProcessor, VTInputReader::IProcessor, IVTShell
 		FARString msg(m);
 		msg.Insert(0, L'\n');
 		msg.Append(L'\n');
-		const DWORD64 saved_color = GetColor();
-		SetColor(COL_HELPTOPIC, true);
+		const uint64_t saved_color = GetColor();
+		SetFarColor(COL_HELPTOPIC, true);
 		DWORD dw;
 		WINPORT(WriteConsole)(NULL, msg.CPtr(), msg.GetLength(), &dw, NULL );
 		SetColor(saved_color, true);
